Class: Spark::Rake::SpeckTask
- Inherits:
-
Object
- Object
- Spark::Rake::SpeckTask
- Defined in:
- lib/spark/rake/speck_task.rb
Instance Method Summary collapse
-
#initialize ⇒ SpeckTask
constructor
Called from a Rake execution environment, will define a new Rake task that executes all of your root Specks, recursively.
Constructor Details
#initialize ⇒ SpeckTask
Called from a Rake execution environment, will define a new Rake task that executes all of your root Specks, recursively.
8 9 10 11 12 13 14 15 |
# File 'lib/spark/rake/speck_task.rb', line 8 def initialize desc 'Recursively runs all root Specks' task :run do Speck::specks.select {|s| s.parent == nil } .each {|speck| Spark.playback speck } end end |